
PRO WHATS_IN_NETCDF, datafile

;Reads a Galileo NetCDF file, its variables and attributes. Also reads in the data
;Use for diagnostics

;datafile = 'c:\data\netcdf\19990603_94.nc'
cdfid = NCDF_OPEN(datafile)

info = NCDF_INQUIRE(cdfid)
PRINT, 'There are', info.ngatts, ' global variables and', info.nvars, ' variables of which ',$
   info.ndims, ' are dimensioned','The unlimited dimension is', info.recdim, $
   FORMAT = '(3(A, I2),A,/,A,I2)'

FOR dimid = 0,info.ndims-1 DO BEGIN
  NCDF_DIMINQ, cdfid, dimid, name, sized
  PRINT, 'Dimension ', dimid,  ' Name ', name, ' Size ', sized
ENDFOR

;Global attributes
PRINT, 'Looking at global attributes.....'
FOR attnum = 0, info.ngatts-1 DO BEGIN
  attname = NCDF_ATTNAME(cdfid, attnum, /GLOBAL)
  NCDF_ATTGET, cdfid, attname, value, /GLOBAL
  PRINT, attname, ' is ', STRING(value)
ENDFOR

;Variables
PRINT, ''
PRINT, 'Looking at variables......'
FOR varid = 0, 3 DO BEGIN
  varinq = NCDF_VARINQ(cdfid, varid)
  NCDF_VARGET, cdfid, varinq.name, value
  PRINT, varinq.name, value, FORMAT='($, A, 2X, F6.3)'
  ;Variable attributes
  FOR attnum = 0, varinq.natts-1 DO BEGIN
    attname = NCDF_ATTNAME(cdfid, varinq.name, attnum)
    NCDF_ATTGET, cdfid, varinq.name, attname, value
    PRINT, STRING(value), FORMAT='($, 2X, A)'
  ENDFOR
  PRINT, ''
ENDFOR

;Reading time
time_varid = NCDF_VARID(cdfid, 'time')
IF (time_varid eq -1) THEN MESSAGE, 'Sorry, time variable not in the file'
varinq = NCDF_VARINQ(cdfid, 'time')
NCDF_VARGET, cdfid, varinq.name, time
HELP, time
;Time variable attributes
FOR attnum = 0, varinq.natts-1 DO BEGIN
  attname = NCDF_ATTNAME(cdfid, varinq.name, attnum)
  NCDF_ATTGET, cdfid, varinq.name, attname, value
  PRINT, attname, ':', STRING(value)+'  ', FORMAT='($, 3A)'
ENDFOR
PRINT, ''

;Reading range
range_varid = NCDF_VARID(cdfid, 'range')
IF (range_varid eq -1) THEN MESSAGE, 'Sorry, range variable not in the file'
varinq = NCDF_VARINQ(cdfid, 'range')
NCDF_VARGET, cdfid, varinq.name, range
HELP, range
;Range variable attributes
FOR attnum = 0, varinq.natts-1 DO BEGIN
  attname = NCDF_ATTNAME(cdfid, varinq.name, attnum)
  NCDF_ATTGET, cdfid, varinq.name, attname, value
  PRINT, attname, ':', STRING(value)+'  ', FORMAT='($, 3A)'
ENDFOR
PRINT, ''

;Reading noise
nez_varid = NCDF_VARID(cdfid, 'nez')
IF (nez_varid eq -1) THEN MESSAGE, 'Sorry, nez variable not in the file'
varinq = NCDF_VARINQ(cdfid, 'nez')
NCDF_VARGET, cdfid, varinq.name, nez
HELP, nez
;Noise variable attributes
FOR attnum = 0, varinq.natts-1 DO BEGIN
  attname = NCDF_ATTNAME(cdfid, varinq.name, attnum)
  NCDF_ATTGET, cdfid, varinq.name, attname, value
  PRINT, attname, ':', STRING(value)+'  ', FORMAT='($, 3A)'
ENDFOR
PRINT, ''

;Reading zh
zh_varid = NCDF_VARID(cdfid, 'Zh')
IF (zh_varid eq -1) THEN MESSAGE, 'Sorry, Zh variable not in the file'
varinq = NCDF_VARINQ(cdfid, 'Zh')
NCDF_VARGET, cdfid, varinq.name, zh
HELP, zh
;zh variable attributes
FOR attnum = 0, varinq.natts-1 DO BEGIN
  attname = NCDF_ATTNAME(cdfid, varinq.name, attnum)
  NCDF_ATTGET, cdfid, varinq.name, attname, value
  PRINT, attname, ':', STRING(value)+'  ', FORMAT='($, 3A)'
ENDFOR
PRINT, ''

NCDF_CLOSE, 0

END
